# footing

## Compatibility

`footing` is compatible with Python 3.8 - 3.12.

## Documentation

[View the footing docs here](https://footing.readthedocs.io/)

## Installation

Install `footing` with:

    pip3 install footing

## Contributing Guide

For information on setting up footing for development and contributing changes, view [CONTRIBUTING.md](CONTRIBUTING.md).
